@@ -2135,7 +2135,7 @@ Graph::Easy::As_svg - Output a Graph::Easy as Scalable Vector Graphics (SVG)
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 SYNOPSIS
 
@@ -2162,7 +2162,7 @@ X<grafics>
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 EXPORT
 
@@ -2195,9 +2195,8 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Graph-Easy-As_svg> or by
-email to
-L<bug-graph-easy-as_svg@rt.cpan.org|mailto:bug-graph-easy-as_svg@rt.cpan.org>.
+http://rt.cpan.org/Public/Dist/Display.html?Name=Graph-Easy-As_svg or by
+email to bug-graph-easy-as_svg@rt.cpan.org.
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
